# Tools

This directory contains tools which make use of the Thug honeyclient
which could be useful in order to automate the analysis and/or improve
its efficiency.

## License information

Copyright (C) 2011-2021 Angelo Dell'Aera <angelo.dellaera@honeynet.org>

License: GNU General Public License, version 2; see COPYING.txt
         included in this archive for details.
